<?xml version="1.0" encoding="Windows-1251"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Transform">
	<xsl:output method="xml"/>
	<xsl:variable name="whiteSpaceChars" select="' &#9;&#10;&#13;'"/>
	<ctmtd:info module="Declarant.clsXMLConverterService" scheme="DLAB" docid="ND">  ( "-")</ctmtd:info>
	<xsl:key use="./CONTAINER" name="GoodCont" match="//GTDCONT_ITEM"/>
	<xsl:template match="GTDCONT_ITEM">
		<xsl:value-of select="CONTAINER"/>
		<xsl:if  test="position()!=last()">
			<xsl:text>, </xsl:text>
		</xsl:if>
	</xsl:template>		
	<xsl:template name="SplitTextBySpace">
		<xsl:param name="Text"/>
		<xsl:param name="Len"/>
		<xsl:param name="Simb"/>
		<xsl:choose>
			<xsl:when test="string-length($Text)&lt;$Len">
				<xsl:value-of select="$Text"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="sSubstring">
					<xsl:choose>
						<xsl:when test="starts-with($Text, $Simb)">
							<xsl:value-of select="string(' ')"/>
						</xsl:when>
						<xsl:when test="contains($Text,$Simb)">
							<xsl:value-of select="concat(substring-before($Text,$Simb),$Simb)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="substring($Text,1, $Len)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="TextBefore" select="$sSubstring"/>
				<xsl:variable name="TextBeforeLen" select="string-length($TextBefore)"/>
				<xsl:if test="$TextBeforeLen &lt;= $Len">
					<xsl:variable name="TextAfter" select="substring($Text,$TextBeforeLen+1)"/>
					<xsl:value-of select="$TextBefore"/>
					<xsl:if test="($Len - $TextBeforeLen) >0 and contains($TextAfter, $Simb)">
						<xsl:variable name="sResultAfter">
							<xsl:call-template name="SplitTextBySpace">
								<xsl:with-param name="Text" select="$TextAfter"/>
								<xsl:with-param name="Len" select="$Len - $TextBeforeLen"/>
								<xsl:with-param name="Simb" select="$Simb"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:value-of select="$sResultAfter"/>
					</xsl:if>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
	<xsl:template name="Firms">
		<xsl:param name="NodeName"/>
		<xsl:variable name="FirmNam">
			<xsl:for-each select="//DECLPRIM/DECLPRIM_ITEM">
				<xsl:value-of select="*[name()=concat($NodeName,'2')]"/>
				<xsl:for-each select="ADDTODECLPRIM2/ADDTODECLPRIM2_ITEM">
					<xsl:if  test="string-length(*[name()=concat($NodeName,'31N')])>0">
						<xsl:value-of select="concat(',',*[name()=concat($NodeName,'31N')])"/>
					</xsl:if>
				</xsl:for-each>
				<xsl:for-each select="ADDTODECLPRIM/ADDTODECLPRIM_ITEM">
					<xsl:if  test="string-length(*[name()=concat($NodeName,'3POST')])>0">
						<xsl:value-of select="concat(', ',*[name()=concat($NodeName,'3POST')])"/>
					</xsl:if>
					<xsl:if  test="string-length(*[name()=concat($NodeName,'3SUBD')])>0">
						<xsl:value-of select="concat(', ',*[name()=concat($NodeName,'3SUBD')])"/>
					</xsl:if>
					<xsl:if  test="string-length(*[name()=concat($NodeName,'3CITY')])>0">
						<xsl:value-of select="concat(', ',*[name()=concat($NodeName,'3CITY')])"/>
					</xsl:if>
					<xsl:if  test="string-length(*[name()=concat($NodeName,'3STREET')])>0">
						<xsl:value-of select="concat(', ',*[name()=concat($NodeName,'3STREET')])"/>
					</xsl:if>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:variable>
		<xsl:value-of select="normalize-space($FirmNam)"/>
	</xsl:template>
	<xsl:template match="/ALLDOCUMENTS">
		<SEAMANIFEST>
			<xsl:for-each select="ALLDOCUMENTS_ITEM/DECLPRIM/DECLPRIM_ITEM">
				<xsl:variable name="num" select="//GTD44_ITEM[G441='02011'][1]/G442"/>
				<xsl:variable name="dat" select="substring(//GTD44_ITEM[G441='02011' and G442=$num][1]/G443,1,10)"/>
				<SEAMANIFEST_ITEM>
					<N1><xsl:value-of select="$num"/></N1>
					<SHIPPER>
						<xsl:call-template name="Firms">
							<xsl:with-param name="NodeName" select="'G02'"/>
						</xsl:call-template>
					</SHIPPER>
					<CONSIGNEE>
						<xsl:call-template name="Firms">
							<xsl:with-param name="NodeName" select="'G08'"/>
						</xsl:call-template>
					</CONSIGNEE>
					<NOTIFY_ADDR>
						<xsl:call-template name="Firms">
							<xsl:with-param name="NodeName" select="'G14'"/>
						</xsl:call-template>
					</NOTIFY_ADDR>
					<xsl:variable name="CarInfo">
						<xsl:value-of select="G502"/>
						<xsl:if test="string-length(ADDTODECLPRIM/ADDTODECLPRIM_ITEM/G503POST)>0">
							<xsl:value-of select="concat(', ',ADDTODECLPRIM/ADDTODECLPRIM_ITEM/G503POST)"/>
						</xsl:if>
						<xsl:if test="string-length(M501)>0">
							<xsl:value-of select="concat(',  ',M501)"/>
						</xsl:if>
						<xsl:if test="string-length(G507)>0">
							<xsl:value-of select="concat(',  ',G507)"/>
						</xsl:if>
						<xsl:if test="string-length(G500)>0">
							<xsl:value-of select="concat(',  ',G500)"/>
						</xsl:if>
						<xsl:if test="string-length(ADDTODECLPRIM/ADDTODECLPRIM_ITEM/G503SUBD)>0">
							<xsl:value-of select="concat(', ',ADDTODECLPRIM/ADDTODECLPRIM_ITEM/G503SUBD)"/>
						</xsl:if>
						<xsl:if test="string-length(ADDTODECLPRIM/ADDTODECLPRIM_ITEM/G503CITY)>0">
							<xsl:value-of select="concat(', ',ADDTODECLPRIM/ADDTODECLPRIM_ITEM/G503CITY)"/>
						</xsl:if>
						<xsl:if test="string-length(ADDTODECLPRIM/ADDTODECLPRIM_ITEM/G503STREET)>0">
							<xsl:value-of select="concat(', ',ADDTODECLPRIM/ADDTODECLPRIM_ITEM/G503STREET)"/>
						</xsl:if>
					</xsl:variable>
					<SHIPOWNER><xsl:value-of select="normalize-space($CarInfo)"/></SHIPOWNER>
					<VESSEL>
						<xsl:value-of select="GTDDKD/GTDDKD_ITEM[NGR='18']/NTRANS"/>
					</VESSEL>
					<DATEOFISSUE><xsl:value-of select="$dat"/></DATEOFISSUE>
						<xsl:variable name="Desc1">	
							<xsl:for-each select="DECLDOP/DECLDOP_ITEM">
								<xsl:variable name="DescrGoodA">
									<xsl:value-of select="normalize-space(G312)"/>
									<xsl:for-each select="GTDBACK/GTDBACK_ITEM[GRAPH_NO=31 and string-length(TEXT)>0]">
										<xsl:if test="position()!=last()">
											<xsl:text> </xsl:text>
										</xsl:if>
										<xsl:value-of select="normalize-space(TEXT)"/>
									</xsl:for-each>	
								</xsl:variable>
							<xsl:value-of select="concat(position(),' ',translate($DescrGoodA, $whiteSpaceChars, ' '))" />
							<xsl:text>&#xA;</xsl:text> 
							<xsl:if test="string-length(concat(position(),' ',translate($DescrGoodA, $whiteSpaceChars, ' ')))>31">
								<xsl:value-of select="concat(position(),' ',translate($DescrGoodA, $whiteSpaceChars, ' '))" />
								 <xsl:text>&#xA;</xsl:text> 
							</xsl:if>
						</xsl:for-each>	
					</xsl:variable>
					<xsl:variable name="Desc2">
						<xsl:call-template name="SplitTextBySpace">
							<xsl:with-param name="Text" select="$Desc1"/>
							<xsl:with-param name="Len"  select="260"/>
							<xsl:with-param name="Simb"  select="'&#xA;'"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="Desc">
						<xsl:choose>
							<xsl:when test="string-length($Desc1)=string-length($Desc2)">0</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(substring(substring-after(substring($Desc1,string-length($Desc2)),'&#xA;'),1,1),'#')+1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="($Desc!=0 and count(DECLDOP/DECLDOP_ITEM)&gt;$Desc) or count(DECLDOP/DECLDOP_ITEM)>7">
							<SEAMANIFESTFREIGHT>
								<SEAMANIFESTFREIGHT_ITEM>
									<DOC_ID>0</DOC_ID>
									<GOODS_DESCR>. </GOODS_DESCR>
									<GROSS_WEIGHT><xsl:value-of select="format-number(round(sum(//DECLDOP_ITEM[string-length(G35)>0]/G35) * 1000000) div 1000000,'0.######')"/></GROSS_WEIGHT>
								</SEAMANIFESTFREIGHT_ITEM>	
							</SEAMANIFESTFREIGHT>
							<SEAMANIFESTFREIGHT_DOP>
								<xsl:for-each select="DECLDOP/DECLDOP_ITEM">
									<SEAMANIFESTFREIGHT_DOP_ITEM>
										<xsl:call-template name="ConosamGoods"/>
									</SEAMANIFESTFREIGHT_DOP_ITEM>
								</xsl:for-each>
							</SEAMANIFESTFREIGHT_DOP>	
						</xsl:when>
						<xsl:otherwise>
							<SEAMANIFESTFREIGHT>
								<xsl:for-each select="DECLDOP/DECLDOP_ITEM">
									<SEAMANIFESTFREIGHT_ITEM>
										<xsl:call-template name="ConosamGoods"/>
									</SEAMANIFESTFREIGHT_ITEM>	
								</xsl:for-each>	
							</SEAMANIFESTFREIGHT>
						</xsl:otherwise>	
					</xsl:choose>						
				</SEAMANIFEST_ITEM>		
			</xsl:for-each>
		</SEAMANIFEST>
	</xsl:template>
	<xsl:template name="ConosamGoods">
		<DOC_ID>0</DOC_ID>
		<GOODS_DESCR>
			<xsl:value-of select="normalize-space(G312)"/>
			<xsl:for-each select="GTDBACK/GTDBACK_ITEM[GRAPH_NO=31 and string-length(TEXT)>0]">
				<xsl:if test="position()!=last()">
					<xsl:text> </xsl:text>
				</xsl:if>
				<xsl:value-of select="normalize-space(TEXT)"/>
			</xsl:for-each>	
		</GOODS_DESCR>
		<GROSS_WEIGHT><xsl:value-of select="format-number(round(G35 * 1000000) div 1000000,'0.######')"/></GROSS_WEIGHT>
		<MARKS></MARKS>
		<MEASUREMENT></MEASUREMENT>
		<NUM_OF_PCS>
			<xsl:for-each select="GTDPK/GTDPK_ITEM[string-length(PKVID)>0]">
				<xsl:value-of select="concat(PKVID,'-',PKKOLVO)"/>
				<xsl:if test="position()!=last()">
					<xsl:text>,</xsl:text>
				</xsl:if>
			</xsl:for-each>
		</NUM_OF_PCS>
		<TARE></TARE>
	</xsl:template>
</xsl:stylesheet>
