<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Transform">
	<xsl:output method="xml"/>
	<ctmtd:info module="BTT.clsXMLConverterService" scheme="VTAA" docid="ND">Из транзитной декларации (программа "ВЭД-Транзит")</ctmtd:info>
	<xsl:template name="AddressField">
		<xsl:param name="Field"/>
		<xsl:if test="normalize-space($Field) != '' ">
			<xsl:value-of select="normalize-space($Field)"/>,</xsl:if>
	</xsl:template>
	
	<xsl:template name="MakeAddress">
		<xsl:param name="Pref"/>
		<xsl:call-template name="AddressField">
			<xsl:with-param name="Field" select="*[name()=concat($Pref,'_POSTALCODE')]"/>
		</xsl:call-template>
		<xsl:call-template name="AddressField">
			<xsl:with-param name="Field" select="*[name()=concat($Pref,'_COUNTRYNAME')]"/>
		</xsl:call-template>
		<xsl:call-template name="AddressField">
			<xsl:with-param name="Field" select="*[name()=concat($Pref,'_REGION')]"/>
		</xsl:call-template>
		<xsl:call-template name="AddressField">
			<xsl:with-param name="Field" select="*[name()=concat($Pref,'_CITY')]"/>
		</xsl:call-template>
		<xsl:value-of select="normalize-space(*[name()=concat($Pref,'_STREETHOUSE')])"/>
	</xsl:template>

	<xsl:template match="VTTPRIM">
		<SMGS>
			<xsl:for-each select="//VTTPRIM/VTTPRIM_ITEM">
				<SMGS_ITEM>
					<DOC_N><xsl:value-of select="VTTDOP/VTTDOP_ITEM/VTTDOPPRESDOCS/VTTDOPPRESDOCS_ITEM[DOCCODE='02013']/DOCNUM"/></DOC_N>
					<G1_1><xsl:value-of select="G022"/></G1_1>
					<G1_2>
						<xsl:choose>
							<xsl:when test="FORMXML=2">
								<xsl:call-template name="MakeAddress">
									<xsl:with-param name="Pref" select="'G02'"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="G023"/>
							</xsl:otherwise>
						</xsl:choose>
					</G1_2>
					<G14_N><xsl:value-of select="G06"/></G14_N>
					<G15_N><xsl:value-of select="G35_NTF"/></G15_N>
					<G24_CURRENCY><xsl:value-of select="G221"/></G24_CURRENCY>
					
					<xsl:variable name="CodTOIn" select="G541"/>
					<G3><xsl:value-of select="document('TranspNSIXml.xml')//GDStanANDCust_ITEM[CustName=$CodTOIn]/NAME"/></G3>
					<G3_1><xsl:value-of select="document('TranspNSIXml.xml')//GDStanANDCust_ITEM[CustName=$CodTOIn]/CODESTAN"/></G3_1>
					<G5_1><xsl:value-of select="G082"/></G5_1>
					<G5_2>
						<xsl:choose>
							<xsl:when test="FORMXML=2">
								<xsl:call-template name="MakeAddress">
									<xsl:with-param name="Pref" select="'G08'"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="G083"/>
							</xsl:otherwise>
						</xsl:choose>
					</G5_2>
					<xsl:variable name="CodTOOut" select="GA3"/>
					<G8_1>
						<xsl:value-of select="document('TranspNSIXml.xml')//GDStanANDCust_ITEM[Code=$CodTOOut]/NAMEDOR"/>
						<xsl:if test="string-length(document('TranspNSIXml.xml')//GDStanANDCust_ITEM[Code=$CodTOOut]/NAMEDOR)>0"> ЖД, </xsl:if>
						<xsl:if test="string-length(RWSNAME)>0"> станция </xsl:if>	
						<xsl:value-of select="RWSNAME"/>
					</G8_1>
					<xsl:variable name="CodCrOut" select="document('TranspNSIXml.xml')//Customs_ITEM[Code=$CodTOOut]/CntryCode"/>
					<G8_2><xsl:value-of select="document('TranspNSIXml.xml')//Country_ITEM[ABC2=$CodCrOut]/RailCode"/></G8_2>
					<G8_3><xsl:value-of select="RAILWAYST"/></G8_3>
					<SMGS_BACKPRIM>
						<SMGS_BACKPRIM_ITEM></SMGS_BACKPRIM_ITEM>
					</SMGS_BACKPRIM>
					<SMGS_CARGO>
						<xsl:for-each select="VTTDOP/VTTDOP_ITEM">
							<SMGS_CARGO_ITEM>
								<G10>
									<xsl:variable name="CouCodPk" select="count(VTTDOPPACK/VTTDOPPACK_ITEM/G318)"/>
									<xsl:for-each select="VTTDOPPACK/VTTDOPPACK_ITEM">
										<xsl:variable name="CodPk" select="G318"/>
										<xsl:value-of select="document('TranspNSIXml.xml')//Packing_ITEM[ID=$CodPk]/Name"/>
										<xsl:if  test="$CouCodPk>1 and position()!=last()">,</xsl:if>
									</xsl:for-each>
								</G10>
								<G11><xsl:value-of select="G312"/></G11>
								<KGUSER><xsl:value-of select="round(G35 * 1000) div 1000"/></KGUSER>
								<MEST><xsl:value-of select="G311"/></MEST>
							</SMGS_CARGO_ITEM>
						</xsl:for-each>
					</SMGS_CARGO>
					<SMGS_OSZAYAV>
						<SMGS_OSZAYAV_ITEM>
						</SMGS_OSZAYAV_ITEM>
					</SMGS_OSZAYAV>
					<SMGS_PLOMB45>
						<SMGS_PLOMB45_ITEM>
						</SMGS_PLOMB45_ITEM>
					</SMGS_PLOMB45>	
					<SMGS_PRILDOC>
						<SMGS_PRILDOC_ITEM></SMGS_PRILDOC_ITEM>
					</SMGS_PRILDOC>
					<SMGS_STATIONS>
						<SMGS_STATIONS_ITEM></SMGS_STATIONS_ITEM>
					</SMGS_STATIONS>
					<SMGS_VAGONS>
					<xsl:choose>
						<xsl:when test="count(GTDDKD/GTDDKD_ITEM[NGR='18'])>0">
							<xsl:for-each select="GTDDKD/GTDDKD_ITEM[NGR='18']">
								<SMGS_VAGONS_ITEM>
									<VAGON><xsl:value-of select="NTRANS"/></VAGON>
								</SMGS_VAGONS_ITEM>
							</xsl:for-each>
						</xsl:when>
						<xsl:when test="string-length(G181)>0">
							<SMGS_VAGONS_ITEM>
								<VAGON><xsl:value-of select="G181"/></VAGON>
							</SMGS_VAGONS_ITEM>
						</xsl:when>
					</xsl:choose>
					</SMGS_VAGONS>
				</SMGS_ITEM>	
			</xsl:for-each>
		</SMGS>
	</xsl:template>
</xsl:stylesheet>
